@@ -22,18 +22,27 @@ return function (uri, callback)
             return
         end
         for _, ref in ipairs(loc.ref) do
-            if ref.type == 'setlocal' then
+            if ref.type == 'setlocal' and ref.value then
                 await.delay()
                 local refNode = vm.compileNode(ref)
+                local value = ref.value
 
-                if not vm.canCastType(uri, locNode, refNode) then
+                if value.type == 'getfield'
+                or value.type == 'getindex' then
+                    -- 由于无法对字段进行类型收窄，
+                    -- 因此将假值移除再进行检查
+                    refNode = refNode:copy():setTruthy()
+                end
+
+                local errs = {}
+                if not vm.canCastType(uri, locNode, refNode, errs) then
                     callback {
                         start   = ref.start,
                         finish  = ref.finish,
                         message = lang.script('DIAG_CAST_LOCAL_TYPE', {
                             def = vm.getInfer(locNode):view(uri),
                             ref = vm.getInfer(refNode):view(uri),
-                        }),
+                        }) .. '\n' .. vm.viewTypeErrorMessage(uri, errs),
                     }
                 end
             end
